candidate_pathnames

Function candidate_pathnames 

pub fn candidate_pathnames(
    pathname: &str,
    options: PathnameFindOptions,
) -> Vec<String>
It’s presumably cheep to concatinate all the pathnames, relative to the cost of testing for files, and this simplifies overall.