pub fn kpathsea_backend() -> (KpathseaBackend, &'static str)Expand description
The backend this process resolved, with a short reason. Forces the KPSE
initialization so the answer is always the real one.
pub fn kpathsea_backend() -> (KpathseaBackend, &'static str)The backend this process resolved, with a short reason. Forces the KPSE
initialization so the answer is always the real one.